let totalChart = 'abcdefghijklmiopqrstuvwxyzABCDEFGHIJKLMIOPQRSTUVWXYZ';

export default {
  getRandomStr(length) {
    return new Array(length).fill('').map(i => totalChart[parseInt(Math.random() * totalChart.length)]).join('');
  },
  timeTransDesc(s) {
    s = parseInt(s)
    // 按秒显示
    if (s <= 60) return `${s}秒`
    let minute = parseInt(s / 60)
    // 按分钟显示
    if (s > 60 && minute <= 60) {
      return `${minute}分钟${s - 60 * minute}秒`
    }
    let hour = parseInt(s / 3600)
    // 按小时显示
    if (minute > 60 && hour <= 24) {
      let extreMinute = minute - hour * 60
      return `${hour}小时${extreMinute ? extreMinute + '分钟' : ''}`
    }
    // 按天显示
    let day = parseInt(s / 86400)
    let extraHour = hour - day * 24
    return `${day}天${extraHour ? extraHour + '小时' : ''}`
  },
  // 获取输入节点
  getLastNodes(code, nodeList, edges) {
    let lastLinks = edges.filter(i => i.target === code)
    return lastLinks.map(link => {
      return nodeList.find(i => i.code === link.source)
    })
  },
  // 设置分类的id串
  setCategoryIds(ids, item) {
    item.ids = [...ids, item.id]
    if (item.children) {
      item.children.forEach(i => this.setCategoryIds(item.ids, i))
    }
  },
  // 整理分类树状结构
  countCategoryTree(whole) {
    whole.forEach(item => {
      item.children = whole.filter(i => i.parentId === item.id)
    })
    return whole.filter(i => i.parentId === 0)
  },
  // 过滤分类
  getFilterCategories(category, key) {
    if (category.cateName.includes(key)) return true
    else if (category.children.find(i => this.getFilterCategories(i, key))) {
      return true
    }
    return false
  },
}
export const nameRules = [
  {required: true, message: '请输入分类名称', trigger: 'blur'},
  {min: 2, max: 20, message: '名称长度在 2 到 20 个字符', trigger: 'blur'},
  {
    trigger: 'blur', validator(rule, value, callback) {
      if (/^[a-zA-Z0-9_\u4e00-\u9fa5]+$/.test(value)) {
        callback()
      } else {
        callback(new Error('含有非法字符，请重新输入'))
      }
    }
  },
]
const checkNumber = (rule, value, callback) => {
  setTimeout(() => {
    // 判断 0 - 100 之间
    if (value < 0 || value > 100) {
      callback(new Error('请输入 0 - 100 之间的数字值'));
    } else {
      callback();
    }
  }, 100);
};
export const categoryRules = (categoryRules = 'categoryName', orderRules = 'orderIndex') => {
  return {
    [categoryRules]: [...nameRules],
    [orderRules]: [
      {required: true, message: '请输入排序值', trigger: 'change'},
      {validator: checkNumber, trigger: 'change'},
    ],
  };
};
export const countCateTreeDisabled = (tree, id) => {
  console.log(tree)
  tree.forEach(l1 => {
    l1.disabled = l1.id === id;
    if (!l1.children || !l1.children.length) return;
    if (l1.disabled) {
      l1.children.forEach(l2 => (l2.disabled = true));
    } else {
      l1.children.forEach(l2 => (l2.disabled = l2.id === id));
    }
  });
};
export const deepCopy = (obj, map = new WeakMap()) => {
  // 如果 obj 是 Date 类型，则创建一个新的 Date 对象并返回
  if (obj instanceof Date) return new Date(obj);
  // 如果 obj 是 RegExp 类型，则创建一个新的 RegExp 对象并返回
  if (obj instanceof RegExp) return new RegExp(obj);

  // 如果 obj 为 null 或者不是对象，则直接返回
  if (obj === null || typeof obj !== 'object') {
    return obj;
  }
  // 如果 map 中已存在 obj 的映射关系，则直接返回该映射关系的值
  if (map.has(obj)) {
    return map.get(obj);
  } else {
    // 创建一个新的 obj 的构造函数的实例
    const res = new obj.constructor();
    // 将 res 添加到 map 中作为 obj 的映射关系
    map.set(obj, res);
    if (res.set) {
      // Set Map WeakMap WeakSet
      if (res.forEach) {
        // Set Map
        // 如果 res 的原型链上存在 set 方法和 forEach 方法
        // 使用 forEach 方法遍历 obj 的每个元素，并将其拷贝后设置到 res 中
        obj.forEach((value, key) => {
          res.set(key, deepCopy(value, map));
        });
      } else {
        // WeakMap WeakSet
        // 如果 res 的原型链上不存在 forEach 方法
        // 抛出异常，提示不支持拷贝 obj 的类型
        throw new Error(obj.constructor.name + '不支持拷贝');
      }
    } else {
      // 如果 res 的原型链上不存在 set 方法
      // 使用 for...in 循环遍历 obj 的每个属性，并将其拷贝后赋值到 res
      for (let key in obj) {
        if (obj.hasOwnProperty(key)) {
          res[key] = deepCopy(obj[key], map);
        }
      }
    }
    return res;
  }
};