import axios from 'axios';
import {ElMessage, ElMessageBox} from 'element-plus';
import {getToken} from './auth'
import mgmt from 'mgmt-component-v3'

axios.defaults.baseURL = window.top._CONFIG.APIHead
// 跨域cookie
axios.defaults.withCredentials = true
//默认超时时间
axios.defaults.timeout = 0;
//返回其他状态码
axios.defaults.validateStatus = function (status) {
  return status >= 200 && status <= 500;
};
//跨域请求，允许保存cookie
axios.defaults.withCredentials = true;

axios.interceptors.request.use(
  config => {
    // config.headers['Blade-Auth'] = 'bearer ' + getToken()
    config.headers['Authorization'] = `Bearer ${getToken()}`;
    return config;
  },
  error => {
    return Promise.reject(error);
  }
);
let defaultMsg = "服务器错误，请稍后再试"
axios.interceptors.response.use(
  response => {
    const res = response.data;
    if (res.code !== 200) {
      if (res.code === 401) {
        ElMessageBox.alert('你已被登出，请重新登录', '提示', {}).then(() => {
          mgmt.toLogin()
        })
      } else {
        ElMessage({message: res.msg || defaultMsg, type: 'error', duration: 3000});
        return Promise.reject(new Error(res.msg || defaultMsg));
      }
    }
    return res
  },
  res => {
    ElMessage({message: defaultMsg, type: 'error', duration: 3000});
    return Promise.reject(new Error(defaultMsg));
  }
);

export default axios
